@@ -22,6 +22,8 @@
 
 struct QMaemo5ValueButton;
 struct QAction;
+struct QCheckBox;
+struct QPushButton;
 
 class MainWindow : public QMainWindow {
   Q_OBJECT
@@ -30,6 +32,9 @@ public:
   explicit MainWindow(QWidget *parent = 0);
   ~MainWindow();
 
+protected:
+  void closeEvent(QCloseEvent *event);
+
 protected slots:
   void saveSettings();
   void loadSettings();
@@ -39,6 +44,8 @@ protected slots:
 private:
   QMaemo5ValueButton *from_button, *to_button;
   QAction *active_action;
+  QCheckBox *cb_enable;
+  QPushButton *done_btn;
 };
 
 #endif // MAINWINDOW_H
